@@ -55,7 +55,7 @@
 #' To update your code with the same reduction as `reduce_right()`,
 #' simply reverse your vector and use a left reduction:
 #'
-#' ```{r}
+#' ```r
 #' # Before:
 #' reduce_right(1:3, f)
 #'
@@ -155,7 +155,12 @@ reduce_impl <- function(.x, .f, ..., .init, .dir, .acc = FALSE) {
   for (i in seq_along(idx)) {
     prev <- out
     elt <- .x[[idx[[i]]]]
-    out <- fn(out, elt, ...)
+
+    if (has_force_and_call) {
+      out <- forceAndCall(2, fn, out, elt, ...)
+    } else {
+      out <- fn(out, elt, ...)
+    }
 
     if (is_done_box(out)) {
       return(reduce_early(out, prev, .acc, acc_out, acc_idx[[i]], left))
@@ -271,7 +276,11 @@ reduce2_impl <- function(.x, .y, .f, ..., .init, .left = TRUE, .acc = FALSE) {
     x_i <- x_idx[[i]]
     y_i <- y_idx[[i]]
 
-    out <- .f(out, .x[[x_i]], .y[[y_i]], ...)
+    if (has_force_and_call) {
+      out <- forceAndCall(3, .f, out, .x[[x_i]], .y[[y_i]], ...)
+    } else {
+      out <- .f(out, .x[[x_i]], .y[[y_i]], ...)
+    }
 
     if (is_done_box(out)) {
       return(reduce_early(out, prev, .acc, acc_out, acc_idx[[i]]))
@@ -321,7 +330,7 @@ seq_len2 <- function(start, end) {
 #'     needs to be 1 element shorter than the vector to be accumulated (`.x`).
 #'     If `.init` is set, `.y` needs to be one element shorted than the
 #'     concatenation of the initial value and `.x`.
-#' 
+#'
 #' @param .f For `accumulate()` `.f` is 2-argument function. The function will
 #'     be passed the accumulated result or initial value as the first argument.
 #'     The next value in sequence is passed as the second argument.
@@ -361,7 +370,7 @@ seq_len2 <- function(start, end) {
 #'   iteration).
 #'
 #' @inheritSection reduce Direction
-#' 
+#'
 #' @section Life cycle:
 #'
 #' `accumulate_right()` is soft-deprecated in favour of the `.dir`
