@@ -2,4 +2,4 @@
 named <- function(x) set_names(x, chr())
 
 # Until we can reexport from rlang
-vars <- quos
+vars <- function(...) rlang::quos(...)
