@@ -1,12 +1,12 @@
 context("pmap")
 
 test_that("input must be a list of vectors", {
-  expect_error(pmap(environment(), identity), "`.l` must be a list, not an environment")
-  expect_error(pmap(list(environment()), identity), "Element 1 of `.l` must be a vector, not an environment")
+  expect_bad_type_error(pmap(environment(), identity), "`.l` must be a list, not an environment")
+  expect_bad_type_error(pmap(list(environment()), identity), "Element 1 of `.l` must be a vector, not an environment")
 })
 
 test_that("elements must be same length", {
-  expect_error(pmap(list(1:2, 1:3), identity), "Element 1 of `.l` must have length 1 or 3, not 2")
+  expect_bad_element_length_error(pmap(list(1:2, 1:3), identity), "Element 1 of `.l` must have length 1 or 3, not 2")
 })
 
 test_that("handles any length 0 input", {
@@ -47,6 +47,11 @@ test_that("outputs are suffixes have correct type", {
   expect_is(pmap_dbl(list(x), mean), "numeric")
   expect_is(pmap_chr(list(x), paste), "character")
   expect_is(pmap_raw(list(x), as.raw), "raw")
+})
+
+test_that("outputs are suffixes have correct type for data frames", {
+  skip_if_not_installed("dplyr")
+  x <- 1:3
   expect_is(pmap_dfr(list(x), as.data.frame), "data.frame")
   expect_is(pmap_dfc(list(x), as.data.frame), "data.frame")
 })
